@@ -1,5 +1,5 @@
 package Module::Build::Tiny;
-$Module::Build::Tiny::VERSION = '0.047';
+$Module::Build::Tiny::VERSION = '0.048';
 use strict;
 use warnings;
 use Exporter 5.57 'import';
@@ -161,15 +161,23 @@ my %actions = (
 	},
 );
 
+sub get_arguments {
+	my @sources = @_;
+	my %opt;
+	GetOptionsFromArray($_, \%opt, qw/install_base=s install_path=s% installdirs=s destdir=s prefix=s config=s% uninst:1 verbose:1 dry_run:1 pureperl-only:1 create_packlist=i jobs=i/) for (@sources);
+	$_ = detildefy($_) for grep { defined } @opt{qw/install_base destdir prefix/}, values %{ $opt{install_path} };
+	$opt{config} = ExtUtils::Config->new($opt{config});
+	$opt{meta} = get_meta();
+	$opt{install_paths} = ExtUtils::InstallPaths->new(%opt, dist_name => $opt{meta}->name);
+	return %opt;
+}
+
 sub Build {
 	my $action = @ARGV && $ARGV[0] =~ /\A\w+\z/ ? shift @ARGV : 'build';
 	die "No such action '$action'\n" if not $actions{$action};
 	my($env, $bargv) = @{ decode_json(read_file('_build_params')) };
-	my %opt;
-	GetOptionsFromArray($_, \%opt, qw/install_base=s install_path=s% installdirs=s destdir=s prefix=s config=s% uninst:1 verbose:1 dry_run:1 pureperl-only:1 create_packlist=i jobs=i/) for ($env, $bargv, \@ARGV);
-	$_ = detildefy($_) for grep { defined } @opt{qw/install_base destdir prefix/}, values %{ $opt{install_path} };
-	@opt{ 'config', 'meta' } = (ExtUtils::Config->new($opt{config}), get_meta());
-	exit $actions{$action}->(%opt, install_paths => ExtUtils::InstallPaths->new(%opt, dist_name => $opt{meta}->name));
+	my %opt = get_arguments($env, $bargv, \@ARGV);
+	exit $actions{$action}->(%opt);
 }
 
 sub Build_PL {
@@ -180,6 +188,15 @@ sub Build_PL {
 	make_executable('Build');
 	my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell($ENV{PERL_MB_OPT}) : ();
 	write_file('_build_params', encode_json([ \@env, \@ARGV ]));
+	if (my $dynamic = $meta->custom('x_dynamic_prereqs')) {
+		my %meta = (%{ $meta->as_struct }, dynamic_config => 0);
+		my %opt = get_arguments(\@env, \@ARGV);
+		require CPAN::Requirements::Dynamic;
+		my $dynamic_parser = CPAN::Requirements::Dynamic->new(%opt);
+		my $prereq = $dynamic_parser->evaluate($dynamic);
+		$meta{prereqs} = $meta->effective_prereqs->with_merged_prereqs($prereq)->as_string_hash;
+		$meta = CPAN::Meta->new(\%meta);
+	}
 	$meta->save(@$_) for ['MYMETA.json'], [ 'MYMETA.yml' => { version => 1.4 } ];
 }
 
@@ -202,7 +219,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
@@ -237,14 +254,14 @@ than 200, yet supports the features needed by most distributions.
 
 =item * Module sharedirs
 
+=item * Dynamic prerequisites
+
 =back
 
 =head2 Not Supported
 
 =over 4
 
-=item * Dynamic prerequisites
-
 =item * HTML documentation generation
 
 =item * Extending Module::Build::Tiny
